# 0.1.2

- More documentation corrections.
- Fixed bug where hsize was not being set for proofs when alternate hash
function (with digest length other than 32) was used.

# 0.1.1

- Corrected some documentation.

# 0.1.0

- Added a virtual machine for proof verification.
- Adapted the original `Tree` class to use the VM.
- Added a hash-XOR tree (XorHashTree).

# 0.0.1

- Initial release.
- Added a `Tree` class.
